# Changelog

<!--next-version-placeholder-->

## v1.4.0 (2022-03-10)
### Feature
* Add `exclude_pattern` to `Section` class ([#18](https://github.com/kalekundert/autoclasstoc/issues/18)) ([`4b796ac`](https://github.com/kalekundert/autoclasstoc/commit/4b796ac5a25bd785e64da4e2f24fdee23f1278ea))

## v1.3.0 (2021-09-14)
### Feature
* Support sphinx~=4.0 ([`405954d`](https://github.com/kalekundert/autoclasstoc/commit/405954d39db5fdb7e3c491a81cce39a82f963231))

### Documentation
* Fix warnings ([`a7d5ade`](https://github.com/kalekundert/autoclasstoc/commit/a7d5ade64c54ef9b3d06e19761874d30407bf331))

## v1.2.1 (2021-09-07)
### Fix
* **utils:** Add missing "f" in "f"string ([`446fa95`](https://github.com/kalekundert/autoclasstoc/commit/446fa95611317922cbc5e1270ef5fc06b79ebeb6))

### Documentation
* Add glooey as an example project ([`34f521f`](https://github.com/kalekundert/autoclasstoc/commit/34f521f4c776d929a43566567f9a09b543c19755))
